@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019 Alice Mikhaylenko <alicem@gnome.org>
+ * Copyright (C) 2019 Alexander Mikhaylenko <exalm7659@gmail.com>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
@@ -9,7 +9,7 @@
 #include "adw-carousel.h"
 
 #include "adw-animation-util.h"
-#include "adw-marshalers.h"
+#include "adw-macros-private.h"
 #include "adw-navigation-direction.h"
 #include "adw-spring-animation.h"
 #include "adw-swipe-tracker.h"
@@ -40,6 +40,8 @@
  * ## CSS nodes
  *
  * `AdwCarousel` has a single CSS node with name `carousel`.
+ *
+ * Since: 1.0
  */
 
 typedef struct {
@@ -77,7 +79,7 @@ struct _AdwCarousel
   double position_shift;
 
   guint scroll_timeout_id;
-  gboolean is_being_allocated;
+  gboolean can_scroll;
 };
 
 static void adw_carousel_buildable_init (GtkBuildableIface *iface);
@@ -343,8 +345,6 @@ animate_child_resize (AdwCarousel *self,
     adw_timed_animation_new (GTK_WIDGET (self), old_size,
                              value, duration, target);
 
-  adw_timed_animation_set_easing (ADW_TIMED_ANIMATION (child->resize_animation), ADW_EASE);
-
   g_signal_connect_swapped (child->resize_animation, "done",
                             G_CALLBACK (resize_animation_done_cb), child);
 
@@ -466,45 +466,11 @@ update_orientation (AdwCarousel *self)
   set_orientable_style_classes (GTK_ORIENTABLE (self));
 }
 
-static void
+static gboolean
 scroll_timeout_cb (AdwCarousel *self)
 {
-  self->scroll_timeout_id = 0;
-}
-
-static gboolean
-navigate_to_direction (AdwCarousel            *self,
-                       AdwNavigationDirection  direction)
-{
-  guint index;
-  guint n_pages;
-
-  n_pages = adw_carousel_get_n_pages (self);
-  if (n_pages == 0)
-    return FALSE;
-
-  index = round (self->position);
-
-  switch (direction) {
-  case ADW_NAVIGATION_DIRECTION_BACK:
-    if (index > 0)
-      index--;
-    else
-      return FALSE;
-    break;
-  case ADW_NAVIGATION_DIRECTION_FORWARD:
-    if (index < n_pages - 1)
-      index++;
-    else
-      return FALSE;
-    break;
-  default:
-    g_assert_not_reached();
-  }
-
-  scroll_to (self, adw_carousel_get_nth_page (self, index), 0);
-
-  return TRUE;
+  self->can_scroll = TRUE;
+  return G_SOURCE_REMOVE;
 }
 
 static gboolean
@@ -523,7 +489,7 @@ scroll_cb (AdwCarousel              *self,
   if (!self->allow_scroll_wheel)
     return GDK_EVENT_PROPAGATE;
 
-  if (self->scroll_timeout_id > 0)
+  if (!self->can_scroll)
     return GDK_EVENT_PROPAGATE;
 
   if (!adw_carousel_get_interactive (self))
@@ -568,107 +534,9 @@ scroll_cb (AdwCarousel              *self,
 
   scroll_to (self, adw_carousel_get_nth_page (self, index), 0);
 
+  self->can_scroll = FALSE;
   self->scroll_timeout_id =
-   g_timeout_add_once (SCROLL_TIMEOUT_DURATION,
-                       (GSourceOnceFunc) scroll_timeout_cb,
-                       self);
-
-  return GDK_EVENT_STOP;
-}
-
-static gboolean
-keynav_cb (AdwCarousel *self,
-           GVariant    *args)
-{
-  guint n_pages;
-  gboolean is_rtl;
-  AdwNavigationDirection direction;
-  GtkDirectionType direction_type;
-
-  if (!adw_carousel_get_interactive (self))
-    return GDK_EVENT_PROPAGATE;
-
-  n_pages = adw_carousel_get_n_pages (self);
-  if (n_pages == 0)
-    return GDK_EVENT_PROPAGATE;
-
-  g_variant_get (args, "u", &direction_type);
-
-  switch (direction_type) {
-  case GTK_DIR_UP:
-  case GTK_DIR_DOWN:
-    if (self->orientation != GTK_ORIENTATION_VERTICAL)
-      return GDK_EVENT_PROPAGATE;
-    break;
-  case GTK_DIR_LEFT:
-  case GTK_DIR_RIGHT:
-    if (self->orientation != GTK_ORIENTATION_HORIZONTAL)
-      return GDK_EVENT_PROPAGATE;
-    break;
-  case GTK_DIR_TAB_BACKWARD:
-  case GTK_DIR_TAB_FORWARD:
-    break;
-  default:
-    g_assert_not_reached();
-  }
-
-  is_rtl = (gtk_widget_get_direction (GTK_WIDGET (self)) == GTK_TEXT_DIR_RTL);
-
-  switch (direction_type) {
-  case GTK_DIR_LEFT:
-    direction = is_rtl ? ADW_NAVIGATION_DIRECTION_FORWARD : ADW_NAVIGATION_DIRECTION_BACK;
-    break;
-  case GTK_DIR_RIGHT:
-    direction = is_rtl ? ADW_NAVIGATION_DIRECTION_BACK : ADW_NAVIGATION_DIRECTION_FORWARD;
-    break;
-  case GTK_DIR_UP:
-  case GTK_DIR_TAB_BACKWARD:
-    direction = ADW_NAVIGATION_DIRECTION_BACK;
-    break;
-  case GTK_DIR_DOWN:
-  case GTK_DIR_TAB_FORWARD:
-    direction = ADW_NAVIGATION_DIRECTION_FORWARD;
-    break;
-  default:
-    g_assert_not_reached();
-  }
-
-  navigate_to_direction (self, direction);
-
-  return GDK_EVENT_STOP;
-}
-
-static gboolean
-keynav_bounds_cb (AdwCarousel *self,
-                  GVariant    *args)
-{
-  guint n_pages;
-  GtkDirectionType direction;
-
-  if (!adw_carousel_get_interactive (self))
-    return GDK_EVENT_PROPAGATE;
-
-  n_pages = adw_carousel_get_n_pages (self);
-  if (n_pages == 0)
-    return GDK_EVENT_PROPAGATE;
-
-  g_variant_get (args, "u", &direction);
-
-  switch (direction) {
-  case GTK_DIR_TAB_BACKWARD:
-    scroll_to (self, adw_carousel_get_nth_page (self, 0), 0);
-    break;
-  case GTK_DIR_TAB_FORWARD:
-    scroll_to (self, adw_carousel_get_nth_page (self, n_pages - 1), 0);
-    break;
-  case GTK_DIR_DOWN:
-  case GTK_DIR_LEFT:
-  case GTK_DIR_RIGHT:
-  case GTK_DIR_UP:
-    return GDK_EVENT_PROPAGATE;
-  default:
-    g_assert_not_reached();
-  }
+   g_timeout_add (SCROLL_TIMEOUT_DURATION, (GSourceFunc) scroll_timeout_cb, self);
 
   return GDK_EVENT_STOP;
 }
@@ -729,7 +597,7 @@ adw_carousel_size_allocate (GtkWidget *widget,
   gboolean is_rtl;
   double snap_point;
 
-  if (!G_APPROX_VALUE (self->position_shift, 0, DBL_EPSILON)) {
+  if (self->position_shift != 0) {
     set_position (self, self->position + self->position_shift);
     adw_swipe_tracker_shift_position (self->tracker, self->position_shift);
     self->position_shift = 0;
@@ -837,8 +705,6 @@ adw_carousel_size_allocate (GtkWidget *widget,
     else
       x += self->distance * child_info->size;
   }
-
-  self->is_being_allocated = FALSE;
 }
 
 static void
@@ -1015,9 +881,11 @@ adw_carousel_class_init (AdwCarouselClass *klass)
   widget_class->compute_expand = adw_widget_compute_expand;
 
   /**
-   * AdwCarousel:n-pages:
+   * AdwCarousel:n-pages: (attributes org.gtk.Property.get=adw_carousel_get_n_pages)
    *
    * The number of pages in a `AdwCarousel`.
+   *
+   * Since: 1.0
    */
   props[PROP_N_PAGES] =
     g_param_spec_uint ("n-pages", NULL, NULL,
@@ -1027,11 +895,13 @@ adw_carousel_class_init (AdwCarouselClass *klass)
                        G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * AdwCarousel:position:
+   * AdwCarousel:position: (attributes org.gtk.Property.get=adw_carousel_get_position)
    *
    * Current scrolling position, unitless.
    *
    * 1 matches 1 page. Use [method@Carousel.scroll_to] for changing it.
+   *
+   * Since: 1.0
    */
   props[PROP_POSITION] =
     g_param_spec_double ("position", NULL, NULL,
@@ -1041,12 +911,14 @@ adw_carousel_class_init (AdwCarouselClass *klass)
                          G_PARAM_READABLE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * AdwCarousel:interactive:
+   * AdwCarousel:interactive: (attributes org.gtk.Property.get=adw_carousel_get_interactive org.gtk.Property.set=adw_carousel_set_interactive)
    *
    * Whether the carousel can be navigated.
    *
    * This can be used to temporarily disable the carousel to only allow
    * navigating it in a certain state.
+   *
+   * Since: 1.0
    */
   props[PROP_INTERACTIVE] =
     g_param_spec_boolean ("interactive", NULL, NULL,
@@ -1054,9 +926,11 @@ adw_carousel_class_init (AdwCarouselClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwCarousel:spacing:
+   * AdwCarousel:spacing: (attributes org.gtk.Property.get=adw_carousel_get_spacing org.gtk.Property.set=adw_carousel_set_spacing)
    *
    * Spacing between pages in pixels.
+   *
+   * Since: 1.0
    */
   props[PROP_SPACING] =
     g_param_spec_uint ("spacing", NULL, NULL,
@@ -1066,7 +940,7 @@ adw_carousel_class_init (AdwCarouselClass *klass)
                        G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwCarousel:scroll-params:
+   * AdwCarousel:scroll-params: (attributes org.gtk.Property.get=adw_carousel_get_scroll_params org.gtk.Property.set=adw_carousel_set_scroll_params)
    *
    * Scroll animation spring parameters.
    *
@@ -1075,6 +949,8 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * ```c
    * adw_spring_params_new (1, 0.5, 500)
    * ```
+   *
+   * Since: 1.0
    */
   props[PROP_SCROLL_PARAMS] =
     g_param_spec_boxed ("scroll-params", NULL, NULL,
@@ -1082,11 +958,13 @@ adw_carousel_class_init (AdwCarouselClass *klass)
                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwCarousel:allow-mouse-drag:
+   * AdwCarousel:allow-mouse-drag: (attributes org.gtk.Property.get=adw_carousel_get_allow_mouse_drag org.gtk.Property.set=adw_carousel_set_allow_mouse_drag)
    *
    * Sets whether the `AdwCarousel` can be dragged with mouse pointer.
    *
    * If the value is `FALSE`, dragging is only available on touch.
+   *
+   * Since: 1.0
    */
   props[PROP_ALLOW_MOUSE_DRAG] =
     g_param_spec_boolean ("allow-mouse-drag", NULL, NULL,
@@ -1094,11 +972,13 @@ adw_carousel_class_init (AdwCarouselClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwCarousel:allow-scroll-wheel:
+   * AdwCarousel:allow-scroll-wheel: (attributes org.gtk.Property.get=adw_carousel_get_allow_scroll_wheel org.gtk.Property.set=adw_carousel_set_allow_scroll_wheel)
    *
    * Whether the widget will respond to scroll wheel events.
    *
    * If the value is `FALSE`, wheel events will be ignored.
+   *
+   * Since: 1.0
    */
   props[PROP_ALLOW_SCROLL_WHEEL] =
     g_param_spec_boolean ("allow-scroll-wheel", NULL, NULL,
@@ -1106,11 +986,13 @@ adw_carousel_class_init (AdwCarouselClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwCarousel:allow-long-swipes:
+   * AdwCarousel:allow-long-swipes: (attributes org.gtk.Property.get=adw_carousel_get_allow_long_swipes org.gtk.Property.set=adw_carousel_set_allow_long_swipes)
    *
    * Whether to allow swiping for more than one page at a time.
    *
    * If the value is `FALSE`, each swipe can only move to the adjacent pages.
+   *
+   * Since: 1.0
    */
   props[PROP_ALLOW_LONG_SWIPES] =
     g_param_spec_boolean ("allow-long-swipes", NULL, NULL,
@@ -1123,6 +1005,8 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * Page reveal duration, in milliseconds.
    *
    * Reveal duration is used when animating adding or removing pages.
+   *
+   * Since: 1.0
    */
   props[PROP_REVEAL_DURATION] =
     g_param_spec_uint ("reveal-duration", NULL, NULL,
@@ -1147,47 +1031,17 @@ adw_carousel_class_init (AdwCarouselClass *klass)
    * It can be used to implement "infinite scrolling" by amending the pages
    * after every scroll.
    *
-   * ::: note
-   *     An empty carousel is indicated by `(int)index == -1`.
+   * Since: 1.0
    */
   signals[SIGNAL_PAGE_CHANGED] =
     g_signal_new ("page-changed",
                   G_TYPE_FROM_CLASS (klass),
                   G_SIGNAL_RUN_LAST,
                   0,
-                  NULL, NULL,
-                  adw_marshal_VOID__UINT,
+                  NULL, NULL, NULL,
                   G_TYPE_NONE,
                   1,
                   G_TYPE_UINT);
-  g_signal_set_va_marshaller (signals[SIGNAL_PAGE_CHANGED],
-                              G_TYPE_FROM_CLASS (klass),
-                              adw_marshal_VOID__UINTv);
-
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_Up, GDK_NO_MODIFIER_MASK,
-                                (GtkShortcutFunc) keynav_cb,
-                                "u", GTK_DIR_UP);
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_Down, GDK_NO_MODIFIER_MASK,
-                                (GtkShortcutFunc) keynav_cb,
-                                "u", GTK_DIR_DOWN);
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_Left, GDK_NO_MODIFIER_MASK,
-                                (GtkShortcutFunc) keynav_cb,
-                                "u", GTK_DIR_LEFT);
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_Right, GDK_NO_MODIFIER_MASK,
-                                (GtkShortcutFunc) keynav_cb,
-                                "u", GTK_DIR_RIGHT);
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_Page_Up, GDK_NO_MODIFIER_MASK,
-                                (GtkShortcutFunc) keynav_cb,
-                                "u", GTK_DIR_TAB_BACKWARD);
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_Page_Down, GDK_NO_MODIFIER_MASK,
-                                (GtkShortcutFunc) keynav_cb,
-                                "u", GTK_DIR_TAB_FORWARD);
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_Home, GDK_NO_MODIFIER_MASK,
-                                (GtkShortcutFunc) keynav_bounds_cb,
-                                "u", GTK_DIR_TAB_BACKWARD);
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_End, GDK_NO_MODIFIER_MASK,
-                                (GtkShortcutFunc) keynav_bounds_cb,
-                                "u", GTK_DIR_TAB_FORWARD);
 
   gtk_widget_class_set_css_name (widget_class, "carousel");
 }
@@ -1204,6 +1058,7 @@ adw_carousel_init (AdwCarousel *self)
 
   self->orientation = GTK_ORIENTATION_HORIZONTAL;
   self->reveal_duration = 0;
+  self->can_scroll = TRUE;
 
   self->tracker = adw_swipe_tracker_new (ADW_SWIPEABLE (self));
   adw_swipe_tracker_set_allow_mouse_drag (self->tracker, TRUE);
@@ -1313,6 +1168,8 @@ adw_carousel_swipeable_init (AdwSwipeableInterface *iface)
  * Creates a new `AdwCarousel`.
  *
  * Returns: the newly created `AdwCarousel`
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_carousel_new (void)
@@ -1326,6 +1183,8 @@ adw_carousel_new (void)
  * @child: a widget to add
  *
  * Prepends @child to @self.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_prepend (AdwCarousel *self,
@@ -1333,7 +1192,6 @@ adw_carousel_prepend (AdwCarousel *self,
 {
   g_return_if_fail (ADW_IS_CAROUSEL (self));
   g_return_if_fail (GTK_IS_WIDGET (widget));
-  g_return_if_fail (gtk_widget_get_parent (widget) == NULL);
 
   adw_carousel_insert (self, widget, 0);
 }
@@ -1344,6 +1202,8 @@ adw_carousel_prepend (AdwCarousel *self,
  * @child: a widget to add
  *
  * Appends @child to @self.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_append (AdwCarousel *self,
@@ -1351,7 +1211,6 @@ adw_carousel_append (AdwCarousel *self,
 {
   g_return_if_fail (ADW_IS_CAROUSEL (self));
   g_return_if_fail (GTK_IS_WIDGET (widget));
-  g_return_if_fail (gtk_widget_get_parent (widget) == NULL);
 
   adw_carousel_insert (self, widget, -1);
 }
@@ -1366,6 +1225,8 @@ adw_carousel_append (AdwCarousel *self,
  *
  * If position is -1, or larger than the number of pages,
  * @child will be appended to the end.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_insert (AdwCarousel *self,
@@ -1377,7 +1238,6 @@ adw_carousel_insert (AdwCarousel *self,
 
   g_return_if_fail (ADW_IS_CAROUSEL (self));
   g_return_if_fail (GTK_IS_WIDGET (widget));
-  g_return_if_fail (gtk_widget_get_parent (widget) == NULL);
   g_return_if_fail (position >= -1);
 
   info = g_new0 (ChildInfo, 1);
@@ -1398,7 +1258,6 @@ adw_carousel_insert (AdwCarousel *self,
     gtk_widget_set_parent (widget, GTK_WIDGET (self));
   }
 
-  self->is_being_allocated = TRUE;
   gtk_widget_queue_allocate (GTK_WIDGET (self));
 
   animate_child_resize (self, info, 1, self->reveal_duration);
@@ -1415,13 +1274,15 @@ adw_carousel_insert (AdwCarousel *self,
  *
  * If position is -1, or larger than the number of pages, @child will be moved
  * at the end.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_reorder (AdwCarousel *self,
                       GtkWidget   *child,
                       int          position)
 {
-  ChildInfo *info, *next_info = NULL;
+  ChildInfo *info, *next_info;
   GList *link, *next_link;
   int old_position, n_pages;
   double closest_point, old_point, new_point;
@@ -1485,16 +1346,13 @@ adw_carousel_reorder (AdwCarousel *self,
     gtk_widget_insert_before (child, GTK_WIDGET (self), NULL);
   }
 
-  if (G_APPROX_VALUE (closest_point, old_point, DBL_EPSILON))
+  if (closest_point == old_point)
     self->position_shift += new_point - old_point;
-  else if ((G_APPROX_VALUE (old_point, closest_point, DBL_EPSILON) || old_point > closest_point) &&
-           (G_APPROX_VALUE (closest_point, new_point, DBL_EPSILON) || closest_point > new_point))
+  else if (old_point >= closest_point && closest_point >= new_point)
     self->position_shift += info->size;
-  else if ((G_APPROX_VALUE (new_point, closest_point, DBL_EPSILON) || new_point > closest_point) &&
-           (G_APPROX_VALUE (closest_point, old_point, DBL_EPSILON) || closest_point > old_point))
+  else if (new_point >= closest_point && closest_point >= old_point)
     self->position_shift -= info->size;
 
-  self->is_being_allocated = TRUE;
   gtk_widget_queue_allocate (GTK_WIDGET (self));
 }
 
@@ -1504,6 +1362,8 @@ adw_carousel_reorder (AdwCarousel *self,
  * @child: a widget to remove
  *
  * Removes @child from @self.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_remove (AdwCarousel *self,
@@ -1531,33 +1391,6 @@ adw_carousel_remove (AdwCarousel *self,
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_N_PAGES]);
 }
 
-static void
-do_scroll_to (AdwCarousel *self,
-              GtkWidget   *widget,
-              gboolean     animate)
-{
-  scroll_to (self, widget, 0);
-
-  if (!animate)
-    adw_animation_skip (self->animation);
-}
-
-typedef struct {
-  AdwCarousel *carousel;
-  GtkWidget *widget;
-  gboolean animate;
-} ScrollData;
-
-static void
-scroll_to_idle_cb (ScrollData *data)
-{
-  do_scroll_to (data->carousel, data->widget, data->animate);
-
-  g_object_unref (data->carousel);
-  g_object_unref (data->widget);
-  g_free (data);
-}
-
 /**
  * adw_carousel_scroll_to:
  * @self: a carousel
@@ -1567,6 +1400,8 @@ scroll_to_idle_cb (ScrollData *data)
  * Scrolls to @widget.
  *
  * If @animate is `TRUE`, the transition will be animated.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_scroll_to (AdwCarousel *self,
@@ -1577,24 +1412,10 @@ adw_carousel_scroll_to (AdwCarousel *self,
   g_return_if_fail (GTK_IS_WIDGET (widget));
   g_return_if_fail (gtk_widget_get_parent (widget) == GTK_WIDGET (self));
 
-  if (self->is_being_allocated) {
-    /* 'self' is still being allocated/resized by GTK
-     * async machinery (initiated from a previous adw_carousel_insert() call)
-     * So in this case let's do the scroll in an idle handler so
-     * it gets executed when everything is in place i.e. after GTK
-     * calls our adw_carousel_size_allocate() function - issue #597 */
-    ScrollData *data;
+  scroll_to (self, widget, 0);
 
-    data = g_new (ScrollData, 1);
-    data->carousel = g_object_ref (self);
-    data->widget = g_object_ref (widget);
-    data->animate = animate;
-
-    g_idle_add_once ((GSourceOnceFunc) scroll_to_idle_cb, data);
-    return;
-  }
-
-  do_scroll_to (self, widget, animate);
+  if (!animate)
+    adw_animation_skip (self->animation);
 }
 
 /**
@@ -1605,6 +1426,8 @@ adw_carousel_scroll_to (AdwCarousel *self,
  * Gets the page at position @n.
  *
  * Returns: (transfer none): the page
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_carousel_get_nth_page (AdwCarousel *self,
@@ -1621,12 +1444,14 @@ adw_carousel_get_nth_page (AdwCarousel *self,
 }
 
 /**
- * adw_carousel_get_n_pages:
+ * adw_carousel_get_n_pages: (attributes org.gtk.Method.get_property=n-pages)
  * @self: a carousel
  *
  * Gets the number of pages in @self.
  *
  * Returns: the number of pages in @self
+ *
+ * Since: 1.0
  */
 guint
 adw_carousel_get_n_pages (AdwCarousel *self)
@@ -1648,7 +1473,7 @@ adw_carousel_get_n_pages (AdwCarousel *self)
 }
 
 /**
- * adw_carousel_get_position:
+ * adw_carousel_get_position: (attributes org.gtk.Method.get_property=position)
  * @self: a carousel
  *
  * Gets current scroll position in @self, unitless.
@@ -1656,6 +1481,8 @@ adw_carousel_get_n_pages (AdwCarousel *self)
  * 1 matches 1 page. Use [method@Carousel.scroll_to] for changing it.
  *
  * Returns: the scroll position
+ *
+ * Since: 1.0
  */
 double
 adw_carousel_get_position (AdwCarousel *self)
@@ -1666,12 +1493,14 @@ adw_carousel_get_position (AdwCarousel *self)
 }
 
 /**
- * adw_carousel_get_interactive:
+ * adw_carousel_get_interactive: (attributes org.gtk.Method.get_property=interactive)
  * @self: a carousel
  *
  * Gets whether @self can be navigated.
  *
  * Returns: whether @self can be navigated
+ *
+ * Since: 1.0
  */
 gboolean
 adw_carousel_get_interactive (AdwCarousel *self)
@@ -1682,7 +1511,7 @@ adw_carousel_get_interactive (AdwCarousel *self)
 }
 
 /**
- * adw_carousel_set_interactive:
+ * adw_carousel_set_interactive: (attributes org.gtk.Method.set_property=interactive)
  * @self: a carousel
  * @interactive: whether @self can be navigated
  *
@@ -1690,6 +1519,8 @@ adw_carousel_get_interactive (AdwCarousel *self)
  *
  * This can be used to temporarily disable the carousel to only allow navigating
  * it in a certain state.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_set_interactive (AdwCarousel *self,
@@ -1708,12 +1539,14 @@ adw_carousel_set_interactive (AdwCarousel *self,
 }
 
 /**
- * adw_carousel_get_spacing:
+ * adw_carousel_get_spacing: (attributes org.gtk.Method.get_property=spacing)
  * @self: a carousel
  *
  * Gets spacing between pages in pixels.
  *
  * Returns: spacing between pages
+ *
+ * Since: 1.0
  */
 guint
 adw_carousel_get_spacing (AdwCarousel *self)
@@ -1724,11 +1557,13 @@ adw_carousel_get_spacing (AdwCarousel *self)
 }
 
 /**
- * adw_carousel_set_spacing:
+ * adw_carousel_set_spacing: (attributes org.gtk.Method.set_property=spacing)
  * @self: a carousel
  * @spacing: the new spacing value
  *
  * Sets spacing between pages in pixels.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_set_spacing (AdwCarousel *self,
@@ -1746,12 +1581,14 @@ adw_carousel_set_spacing (AdwCarousel *self,
 }
 
 /**
- * adw_carousel_get_scroll_params:
+ * adw_carousel_get_scroll_params: (attributes org.gtk.Method.get_property=scroll-params)
  * @self: a carousel
  *
  * Gets the scroll animation spring parameters for @self.
  *
  * Returns: the animation parameters
+ *
+ * Since: 1.0
  */
 AdwSpringParams *
 adw_carousel_get_scroll_params (AdwCarousel *self)
@@ -1762,7 +1599,7 @@ adw_carousel_get_scroll_params (AdwCarousel *self)
 }
 
 /**
- * adw_carousel_set_scroll_params:
+ * adw_carousel_set_scroll_params: (attributes org.gtk.Method.set_property=scroll-params)
  * @self: a carousel
  * @params: the new parameters
  *
@@ -1773,6 +1610,8 @@ adw_carousel_get_scroll_params (AdwCarousel *self)
  * ```c
  * adw_spring_params_new (1, 0.5, 500)
  * ```
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_set_scroll_params (AdwCarousel     *self,
@@ -1790,12 +1629,14 @@ adw_carousel_set_scroll_params (AdwCarousel     *self,
 }
 
 /**
- * adw_carousel_get_allow_mouse_drag:
+ * adw_carousel_get_allow_mouse_drag: (attributes org.gtk.Method.get_property=allow-mouse-drag)
  * @self: a carousel
  *
  * Sets whether @self can be dragged with mouse pointer.
  *
  * Returns: whether @self can be dragged with mouse pointer
+ *
+ * Since: 1.0
  */
 gboolean
 adw_carousel_get_allow_mouse_drag (AdwCarousel *self)
@@ -1806,13 +1647,15 @@ adw_carousel_get_allow_mouse_drag (AdwCarousel *self)
 }
 
 /**
- * adw_carousel_set_allow_mouse_drag:
+ * adw_carousel_set_allow_mouse_drag: (attributes org.gtk.Method.set_property=allow-mouse-drag)
  * @self: a carousel
  * @allow_mouse_drag: whether @self can be dragged with mouse pointer
  *
  * Sets whether @self can be dragged with mouse pointer.
  *
  * If @allow_mouse_drag is `FALSE`, dragging is only available on touch.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_set_allow_mouse_drag (AdwCarousel *self,
@@ -1831,12 +1674,14 @@ adw_carousel_set_allow_mouse_drag (AdwCarousel *self,
 }
 
 /**
- * adw_carousel_get_allow_scroll_wheel:
+ * adw_carousel_get_allow_scroll_wheel: (attributes org.gtk.Method.get_property=allow-scroll-wheel)
  * @self: a carousel
  *
  * Gets whether @self will respond to scroll wheel events.
  *
  * Returns: `TRUE` if @self will respond to scroll wheel events
+ *
+ * Since: 1.0
  */
 gboolean
 adw_carousel_get_allow_scroll_wheel (AdwCarousel *self)
@@ -1847,13 +1692,15 @@ adw_carousel_get_allow_scroll_wheel (AdwCarousel *self)
 }
 
 /**
- * adw_carousel_set_allow_scroll_wheel:
+ * adw_carousel_set_allow_scroll_wheel: (attributes org.gtk.Method.set_property=allow-scroll-wheel)
  * @self: a carousel
  * @allow_scroll_wheel: whether @self will respond to scroll wheel events
  *
  * Sets whether @self will respond to scroll wheel events.
  *
  * If @allow_scroll_wheel is `FALSE`, wheel events will be ignored.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_set_allow_scroll_wheel (AdwCarousel *self,
@@ -1872,12 +1719,14 @@ adw_carousel_set_allow_scroll_wheel (AdwCarousel *self,
 }
 
 /**
- * adw_carousel_get_allow_long_swipes:
+ * adw_carousel_get_allow_long_swipes: (attributes org.gtk.Method.get_property=allow-long-swipes)
  * @self: a carousel
  *
  * Gets whether to allow swiping for more than one page at a time.
  *
  * Returns: `TRUE` if long swipes are allowed
+ *
+ * Since: 1.0
  */
 gboolean
 adw_carousel_get_allow_long_swipes (AdwCarousel *self)
@@ -1888,7 +1737,7 @@ adw_carousel_get_allow_long_swipes (AdwCarousel *self)
 }
 
 /**
- * adw_carousel_set_allow_long_swipes:
+ * adw_carousel_set_allow_long_swipes: (attributes org.gtk.Method.set_property=allow-long-swipes)
  * @self: a carousel
  * @allow_long_swipes: whether to allow long swipes
  *
@@ -1896,6 +1745,8 @@ adw_carousel_get_allow_long_swipes (AdwCarousel *self)
  *
  * If @allow_long_swipes is `FALSE`, each swipe can only move to the adjacent
  * pages.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_set_allow_long_swipes (AdwCarousel *self,
@@ -1914,12 +1765,14 @@ adw_carousel_set_allow_long_swipes (AdwCarousel *self,
 }
 
 /**
- * adw_carousel_get_reveal_duration:
+ * adw_carousel_get_reveal_duration: (attributes org.gtk.Method.get_property=reveal-duration)
  * @self: a carousel
  *
  * Gets the page reveal duration, in milliseconds.
  *
  * Returns: the duration
+ *
+ * Since: 1.0
  */
 guint
 adw_carousel_get_reveal_duration (AdwCarousel *self)
@@ -1930,13 +1783,15 @@ adw_carousel_get_reveal_duration (AdwCarousel *self)
 }
 
 /**
- * adw_carousel_set_reveal_duration:
+ * adw_carousel_set_reveal_duration: (attributes org.gtk.Method.set_property=reveal-duration)
  * @self: a carousel
  * @reveal_duration: the new reveal duration value
  *
  * Sets the page reveal duration, in milliseconds.
  *
  * Reveal duration is used when animating adding or removing pages.
+ *
+ * Since: 1.0
  */
 void
 adw_carousel_set_reveal_duration (AdwCarousel *self,
