@@ -72,47 +72,8 @@
  * [class@TimedAnimation].
  *
  * New values may be added to this enumeration over time.
- */
-
-/**
- * ADW_EASE:
  *
- * Cubic bezier tweening, with control points in (0.25, 0.1) and (0.25, 1.0).
- *
- * Increases in velocity towards the middle of the animation, slowing back down
- * at the end.
- *
- * Since: 1.7
- */
-
-/**
- * ADW_EASE_IN:
- *
- * Cubic bezier tweening, with control points in (0.42, 0.0) and (1.0, 1.0).
- *
- * Starts off slowly, with the speed of the animation increasing until complete.
- *
- * Since: 1.7
- */
-
-/**
- * ADW_EASE_OUT:
- *
- * Cubic bezier tweening, with control points in (0.0, 0.0) and (0.58, 1.0).
- *
- * Starts quickly, slowing down the animation until complete.
- *
- * Since: 1.7
- */
-
-/**
- * ADW_EASE_IN_OUT:
- *
- * Cubic bezier tweening, with control points in (0.42, 0.0) and (0.58, 1.0).
- *
- * Starts off slowly, speeds up in the middle, and then slows down again.
- *
- * Since: 1.7
+ * Since: 1.0
  */
 
 static inline double
@@ -275,14 +236,14 @@ static inline double
 ease_in_expo (double t,
               double d)
 {
-  return G_APPROX_VALUE (t, 0, DBL_EPSILON) ? 0.0 : pow (2, 10 * (t / d - 1));
+  return (t == 0) ? 0.0 : pow (2, 10 * (t / d - 1));
 }
 
 static double
 ease_out_expo (double t,
                double d)
 {
-  return G_APPROX_VALUE (t, d, DBL_EPSILON) ? 1.0 : -pow (2, -10 * t / d) + 1;
+  return (t == d) ? 1.0 : -pow (2, -10 * t / d) + 1;
 }
 
 static inline double
@@ -291,10 +252,10 @@ ease_in_out_expo (double t,
 {
   double p;
 
-  if (G_APPROX_VALUE (t, 0, DBL_EPSILON))
+  if (t == 0)
     return 0.0;
 
-  if (G_APPROX_VALUE (t, d, DBL_EPSILON))
+  if (t == d)
     return 1.0;
 
   p = t / (d / 2);
@@ -347,7 +308,7 @@ ease_in_elastic (double t,
   double s = p / 4;
   double q = t / d;
 
-  if (G_APPROX_VALUE (q, 1, DBL_EPSILON))
+  if (q == 1)
     return 1.0;
 
   q -= 1;
@@ -363,7 +324,7 @@ ease_out_elastic (double t,
   double s = p / 4;
   double q = t / d;
 
-  if (G_APPROX_VALUE (q, 1, DBL_EPSILON))
+  if (q == 1)
     return 1.0;
 
   return pow (2, -10 * q) * sin ((q * d - s) * (2 * G_PI) / p) + 1.0;
@@ -377,7 +338,7 @@ ease_in_out_elastic (double t,
   double s = p / 4;
   double q = t / (d / 2);
 
-  if (G_APPROX_VALUE (q, 2, DBL_EPSILON))
+  if (q == 2)
     return 1.0;
 
   if (q < 1) {
@@ -466,70 +427,6 @@ ease_in_out_bounce (double t,
     return ease_out_bounce (t * 2 - d, d) * 0.5 + 1.0 * 0.5;
 }
 
-static inline double
-x_for_t (double t,
-         double x_1,
-         double x_2)
-{
-  double omt = 1.0 - t;
-
-  return 3.0 * omt * omt * t * x_1
-       + 3.0 * omt * t * t * x_2
-       + t * t * t;
-}
-
-static inline double
-y_for_t (double t,
-         double y_1,
-         double y_2)
-{
-  double omt = 1.0 - t;
-
-  return 3.0 * omt * omt * t * y_1
-       + 3.0 * omt * t * t * y_2
-       + t * t * t;
-}
-
-static inline double
-t_for_x (double x,
-         double x_1,
-         double x_2)
-{
-  double min_t = 0, max_t = 1;
-  int i;
-
-  for (i = 0; i < 30; ++i) {
-    double guess_t = (min_t + max_t) / 2.0;
-    double guess_x = x_for_t (guess_t, x_1, x_2);
-
-    if (x < guess_x)
-      max_t = guess_t;
-    else
-      min_t = guess_t;
-  }
-
-  return (min_t + max_t) / 2.0;
-}
-
-static double
-ease_cubic_bezier (double t,
-                   double d,
-                   double x_1,
-                   double y_1,
-                   double x_2,
-                   double y_2)
-{
-  double p = t / d;
-
-  if (G_APPROX_VALUE (p, 0.0, DBL_EPSILON))
-    return 0.0;
-
-  if (G_APPROX_VALUE (p, 1.0, DBL_EPSILON))
-    return 1.0;
-
-  return y_for_t (t_for_x (p, x_1, x_2), y_1, y_2);
-}
-
 /**
  * adw_easing_ease:
  * @self: an easing value
@@ -540,6 +437,8 @@ ease_cubic_bezier (double t,
  * @value should generally be in the [0, 1] range.
  *
  * Returns: the easing for @value
+ *
+ * Since: 1.0
  */
 double
 adw_easing_ease (AdwEasing self,
@@ -608,14 +507,6 @@ adw_easing_ease (AdwEasing self,
       return ease_out_bounce (value, 1);
     case ADW_EASE_IN_OUT_BOUNCE:
       return ease_in_out_bounce (value, 1);
-    case ADW_EASE:
-      return ease_cubic_bezier (value, 1, 0.25, 0.1, 0.25, 1.0);
-    case ADW_EASE_IN:
-      return ease_cubic_bezier (value, 1, 0.42, 0.0, 1.0, 1.0);
-    case ADW_EASE_OUT:
-      return ease_cubic_bezier (value, 1, 0.0, 0.0, 0.58, 1.0);
-    case ADW_EASE_IN_OUT:
-      return ease_cubic_bezier (value, 1, 0.42, 0.0, 0.58, 1.0);
     default:
       g_assert_not_reached ();
   }
