@@ -11,17 +11,14 @@
 
 #include "adw-animation-util.h"
 #include "adw-action-row.h"
-#include "adw-breakpoint-bin.h"
 #include "adw-leaflet.h"
-#include "adw-navigation-view.h"
+#include "adw-macros-private.h"
 #include "adw-preferences-group-private.h"
 #include "adw-preferences-page-private.h"
 #include "adw-toast-overlay.h"
-#include "adw-view-stack.h"
-#include "adw-widget-utils-private.h"
-
-#define VIEW_SWITCHER_PAGE_THRESHOLD 110
-#define VIEW_SWITCHER_FALLBACK_THRESHOLD 400
+#include "adw-view-switcher.h"
+#include "adw-view-switcher-bar.h"
+#include "adw-view-switcher-title.h"
 
 /**
  * AdwPreferencesWindow:
@@ -41,14 +38,14 @@
  * `AdwPreferencesWindow` has a main CSS node with the name `window` and the
  * style class `.preferences`.
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 
 typedef struct
 {
   AdwToastOverlay *toast_overlay;
-  AdwNavigationView *subpages_nav_view;
-  GtkWidget *breakpoint_bin;
+  AdwLeaflet *subpages_leaflet;
+  GtkWidget *preferences;
   GtkStack *content_stack;
   AdwViewStack *pages_stack;
   GtkToggleButton *search_button;
@@ -56,21 +53,15 @@ typedef struct
   GtkListBox *search_results;
   GtkStack *search_stack;
   GtkStack *title_stack;
-  GtkWidget *view_switcher_stack;
-  GtkWidget *view_switcher;
-  GtkWidget *title;
-  AdwBreakpoint *breakpoint;
+  AdwViewSwitcherBar *view_switcher_bar;
+  AdwViewSwitcherTitle *view_switcher_title;
 
   gboolean search_enabled;
   gboolean can_navigate_back;
 
-  GtkFilter *row_filter;
-  GtkFilter *page_filter;
+  GtkFilter *filter;
   GtkFilterListModel *filter_model;
 
-  int n_pages;
-
-  AdwLeaflet *subpages_leaflet;
   GtkWidget *subpage;
 } AdwPreferencesWindowPrivate;
 
@@ -94,6 +85,50 @@ enum {
 
 static GParamSpec *props[LAST_PROP];
 
+/* Copied and modified from gtklabel.c, separate_uline_pattern() */
+static char *
+strip_mnemonic (const char *src)
+{
+  char *new_str = g_new (char, strlen (src) + 1);
+  char *dest = new_str;
+  gboolean underscore = FALSE;
+
+  while (*src) {
+    gunichar c;
+    const char *next_src;
+
+    c = g_utf8_get_char (src);
+    if (c == (gunichar) -1) {
+      g_warning ("Invalid input string");
+
+      g_free (new_str);
+
+      return NULL;
+    }
+
+    next_src = g_utf8_next_char (src);
+
+    if (underscore) {
+      while (src < next_src)
+        *dest++ = *src++;
+
+      underscore = FALSE;
+    } else {
+      if (c == '_'){
+        underscore = TRUE;
+        src = next_src;
+      } else {
+        while (src < next_src)
+          *dest++ = *src++;
+      }
+    }
+  }
+
+  *dest = 0;
+
+  return new_str;
+}
+
 static char *
 make_comparable (const char        *src,
                  AdwPreferencesRow *row,
@@ -115,7 +150,7 @@ make_comparable (const char        *src,
   }
 
   if (allow_underline && adw_preferences_row_get_use_underline (row)) {
-    char *comparable = adw_strip_mnemonic (plaintext);
+    char *comparable = strip_mnemonic (plaintext);
     g_free (plaintext);
     return comparable;
   }
@@ -172,15 +207,15 @@ get_n_pages (AdwPreferencesWindow *self)
   return count;
 }
 
-static char *
+static gchar *
 create_search_row_subtitle (AdwPreferencesWindow *self,
-                            AdwPreferencesRow    *row)
+                            GtkWidget            *row)
 {
   GtkWidget *group, *page;
   const char *group_title = NULL;
   char *page_title = NULL;
 
-  group = gtk_widget_get_ancestor (GTK_WIDGET (row), ADW_TYPE_PREFERENCES_GROUP);
+  group = gtk_widget_get_ancestor (row, ADW_TYPE_PREFERENCES_GROUP);
 
   if (group) {
     group_title = adw_preferences_group_get_title (ADW_PREFERENCES_GROUP (group));
@@ -195,18 +230,10 @@ create_search_row_subtitle (AdwPreferencesWindow *self,
     const char *title = adw_preferences_page_get_title (ADW_PREFERENCES_PAGE (page));
 
     if (adw_preferences_page_get_use_underline (ADW_PREFERENCES_PAGE (page)))
-      page_title = adw_strip_mnemonic (title);
+      page_title = strip_mnemonic (title);
     else
       page_title = g_strdup (title);
 
-    if (adw_preferences_row_get_use_markup (row)) {
-      char *tmp = page_title;
-
-      page_title = g_markup_escape_text (page_title, -1);
-
-      g_free (tmp);
-    }
-
     if (g_strcmp0 (page_title, "") == 0)
       g_clear_pointer (&page_title, g_free);
   }
@@ -237,17 +264,13 @@ new_search_row_for_preference (AdwPreferencesRow    *row,
 
   g_assert (ADW_IS_PREFERENCES_ROW (row));
 
-  subtitle = create_search_row_subtitle (self, row);
+  subtitle = create_search_row_subtitle (self, GTK_WIDGET (row));
   page = gtk_widget_get_ancestor (GTK_WIDGET (row), ADW_TYPE_PREFERENCES_PAGE);
 
   widget = ADW_ACTION_ROW (adw_action_row_new ());
   gtk_list_box_row_set_activatable (GTK_LIST_BOX_ROW (widget), TRUE);
-  adw_preferences_row_set_use_markup (ADW_PREFERENCES_ROW (widget),
-                                      adw_preferences_row_get_use_markup (row));
-  adw_preferences_row_set_use_underline (ADW_PREFERENCES_ROW (widget),
-                                         adw_preferences_row_get_use_underline (row));
-  adw_preferences_row_set_title (ADW_PREFERENCES_ROW (widget),
-                                 adw_preferences_row_get_title (row));
+  g_object_bind_property (row, "title", widget, "title", G_BINDING_SYNC_CREATE);
+  g_object_bind_property (row, "use-underline", widget, "use-underline", G_BINDING_SYNC_CREATE);
   adw_action_row_set_subtitle (widget, subtitle);
 
   g_object_set_data (G_OBJECT (widget), "page", page);
@@ -300,7 +323,7 @@ search_results_unmap (AdwPreferencesWindow *self)
 }
 
 static void
-try_remove_legacy_subpages (AdwPreferencesWindow *self)
+try_remove_subpages (AdwPreferencesWindow *self)
 {
   AdwPreferencesWindowPrivate *priv = adw_preferences_window_get_instance_private (self);
   GtkWidget *child;
@@ -308,7 +331,7 @@ try_remove_legacy_subpages (AdwPreferencesWindow *self)
   if (adw_leaflet_get_child_transition_running (priv->subpages_leaflet))
     return;
 
-  if (adw_leaflet_get_visible_child (priv->subpages_leaflet) == GTK_WIDGET (priv->subpages_nav_view))
+  if (adw_leaflet_get_visible_child (priv->subpages_leaflet) == priv->preferences)
     priv->subpage = NULL;
 
   child = gtk_widget_get_first_child (GTK_WIDGET (priv->subpages_leaflet));
@@ -317,41 +340,21 @@ try_remove_legacy_subpages (AdwPreferencesWindow *self)
 
     child = gtk_widget_get_next_sibling (child);
 
-    if (page != GTK_WIDGET (priv->subpages_nav_view) && page != priv->subpage)
+    if (page != priv->preferences && page != priv->subpage)
       adw_leaflet_remove (priv->subpages_leaflet, page);
   }
 }
 
 static void
-update_view_switcher (AdwPreferencesWindow *self)
+subpages_leaflet_child_transition_running_cb (AdwPreferencesWindow *self)
 {
-  AdwPreferencesWindowPrivate *priv = adw_preferences_window_get_instance_private (self);
-  AdwBreakpoint *breakpoint;
-  AdwBreakpointCondition *main_condition, *fallback_condition, *condition;
+  try_remove_subpages (self);
+}
 
-  main_condition =
-    adw_breakpoint_condition_new_length (ADW_BREAKPOINT_CONDITION_MAX_WIDTH,
-                                         VIEW_SWITCHER_PAGE_THRESHOLD * MAX (1, priv->n_pages),
-                                         ADW_LENGTH_UNIT_PT);
-  fallback_condition =
-    adw_breakpoint_condition_new_length (ADW_BREAKPOINT_CONDITION_MAX_WIDTH,
-                                         VIEW_SWITCHER_FALLBACK_THRESHOLD,
-                                         ADW_LENGTH_UNIT_PX);
-
-  condition = adw_breakpoint_condition_new_or (main_condition, fallback_condition);
-
-  adw_breakpoint_set_condition (priv->breakpoint, condition);
-
-  breakpoint = adw_breakpoint_bin_get_current_breakpoint (ADW_BREAKPOINT_BIN (priv->breakpoint_bin));
-
-  if (!breakpoint && priv->n_pages > 1)
-    gtk_stack_set_visible_child (GTK_STACK (priv->view_switcher_stack), priv->view_switcher);
-  else
-    gtk_stack_set_visible_child (GTK_STACK (priv->view_switcher_stack), priv->title);
-
-  adw_breakpoint_condition_free (condition);
-
-  gtk_filter_changed (priv->page_filter, GTK_FILTER_CHANGE_DIFFERENT);
+static void
+subpages_leaflet_visible_child_cb (AdwPreferencesWindow *self)
+{
+  try_remove_subpages (self);
 }
 
 static void
@@ -360,7 +363,7 @@ title_stack_notify_transition_running_cb (AdwPreferencesWindow *self)
   AdwPreferencesWindowPrivate *priv = adw_preferences_window_get_instance_private (self);
 
   if (gtk_stack_get_transition_running (priv->title_stack) ||
-      gtk_stack_get_visible_child (priv->title_stack) != priv->view_switcher_stack)
+      gtk_stack_get_visible_child (priv->title_stack) != GTK_WIDGET (priv->view_switcher_title))
     return;
 
   gtk_editable_set_text (GTK_EDITABLE (priv->search_entry), "");
@@ -372,7 +375,7 @@ title_stack_notify_visible_child_cb (AdwPreferencesWindow *self)
   AdwPreferencesWindowPrivate *priv = adw_preferences_window_get_instance_private (self);
 
   if (adw_get_enable_animations (GTK_WIDGET (priv->title_stack)) ||
-      gtk_stack_get_visible_child (priv->title_stack) != priv->view_switcher_stack)
+      gtk_stack_get_visible_child (priv->title_stack) != GTK_WIDGET (priv->view_switcher_title))
     return;
 
   gtk_editable_set_text (GTK_EDITABLE (priv->search_entry), "");
@@ -423,7 +426,7 @@ search_changed_cb (AdwPreferencesWindow *self)
   AdwPreferencesWindowPrivate *priv = adw_preferences_window_get_instance_private (self);
   guint n;
 
-  gtk_filter_changed (priv->row_filter, GTK_FILTER_CHANGE_DIFFERENT);
+  gtk_filter_changed (priv->filter, GTK_FILTER_CHANGE_DIFFERENT);
 
   n = g_list_model_get_n_items (G_LIST_MODEL (priv->filter_model));
 
@@ -550,11 +553,11 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
   object_class->dispose = adw_preferences_window_dispose;
 
   /**
-   * AdwPreferencesWindow:visible-page:
+   * AdwViewStack:visible-page: (attributes org.gtk.Property.get=adw_preferences_window_get_visible_page org.gtk.Property.set=adw_preferences_window_set_visible_page)
    *
    * The currently visible page.
    *
-   * Deprecated: 1.6: Use [class@PreferencesDialog].
+   * Since: 1.0
    */
   props[PROP_VISIBLE_PAGE] =
     g_param_spec_object ("visible-page", NULL, NULL,
@@ -562,13 +565,13 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwPreferencesWindow:visible-page-name:
+   * AdwViewStack:visible-page-name: (attributes org.gtk.Property.get=adw_preferences_window_get_visible_page_name org.gtk.Property.set=adw_preferences_window_set_visible_page_name)
    *
    * The name of the currently visible page.
    *
-   * See [property@PreferencesWindow:visible-page].
+   * See [property@ViewStack:visible-child].
    *
-   * Deprecated: 1.6: Use [class@PreferencesDialog].
+   * Since: 1.0
    */
   props[PROP_VISIBLE_PAGE_NAME] =
     g_param_spec_string ("visible-page-name", NULL, NULL,
@@ -576,11 +579,11 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwPreferencesWindow:search-enabled:
+   * AdwPreferencesWindow:search-enabled: (attributes org.gtk.Property.get=adw_preferences_window_get_search_enabled org.gtk.Property.set=adw_preferences_window_set_search_enabled)
    *
    * Whether search is enabled.
    *
-   * Deprecated: 1.6: Use [class@PreferencesDialog].
+   * Since: 1.0
    */
   props[PROP_SEARCH_ENABLED] =
     g_param_spec_boolean ("search-enabled", NULL, NULL,
@@ -588,7 +591,7 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
                           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * AdwPreferencesWindow:can-navigate-back:
+   * AdwPreferencesWindow:can-navigate-back: (attributes org.gtk.Property.get=adw_preferences_window_get_can_navigate_back org.gtk.Property.set=adw_preferences_window_set_can_navigate_back)
    *
    * Whether gestures and shortcuts for closing subpages are enabled.
    *
@@ -603,32 +606,23 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
    *
    * For right-to-left locales, gestures and shortcuts are reversed.
    *
-   * Has no effect for subpages added with
-   * [method@PreferencesWindow.push_subpage].
-   *
-   * Deprecated: 1.4: Use [property@NavigationPage:can-pop] instead.
+   * Since: 1.0
    */
   props[PROP_CAN_NAVIGATE_BACK] =
     g_param_spec_boolean ("can-navigate-back", NULL, NULL,
                           FALSE,
-                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_DEPRECATED);
+                          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   g_object_class_install_properties (object_class, LAST_PROP, props);
 
-#ifdef __APPLE__
-  gtk_widget_class_add_binding (widget_class, GDK_KEY_f, GDK_META_MASK, search_open_cb, NULL);
-#else
   gtk_widget_class_add_binding (widget_class, GDK_KEY_f, GDK_CONTROL_MASK, search_open_cb, NULL);
-#endif
-
   gtk_widget_class_add_binding (widget_class, GDK_KEY_Escape, 0, close_cb, NULL);
 
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/org/gnome/Adwaita/ui/adw-preferences-window.ui");
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, toast_overlay);
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, subpages_leaflet);
-  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, subpages_nav_view);
-  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, breakpoint_bin);
+  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, preferences);
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, content_stack);
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, pages_stack);
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, search_button);
@@ -636,12 +630,10 @@ adw_preferences_window_class_init (AdwPreferencesWindowClass *klass)
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, search_results);
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, search_stack);
   gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, title_stack);
-  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, view_switcher_stack);
-  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, view_switcher);
-  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, title);
-  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, breakpoint);
-  gtk_widget_class_bind_template_callback (widget_class, try_remove_legacy_subpages);
-  gtk_widget_class_bind_template_callback (widget_class, update_view_switcher);
+  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, view_switcher_bar);
+  gtk_widget_class_bind_template_child_private (widget_class, AdwPreferencesWindow, view_switcher_title);
+  gtk_widget_class_bind_template_callback (widget_class, subpages_leaflet_child_transition_running_cb);
+  gtk_widget_class_bind_template_callback (widget_class, subpages_leaflet_visible_child_cb);
   gtk_widget_class_bind_template_callback (widget_class, title_stack_notify_transition_running_cb);
   gtk_widget_class_bind_template_callback (widget_class, title_stack_notify_visible_child_cb);
   gtk_widget_class_bind_template_callback (widget_class, notify_visible_page_cb);
@@ -676,19 +668,17 @@ adw_preferences_window_init (AdwPreferencesWindow *self)
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
-  priv->row_filter = GTK_FILTER (gtk_custom_filter_new ((GtkCustomFilterFunc) filter_search_results, self, NULL));
-
-  expr = gtk_property_expression_new (ADW_TYPE_VIEW_STACK_PAGE, NULL, "visible");
-  priv->page_filter = GTK_FILTER (gtk_bool_filter_new (expr));
+  priv->filter = GTK_FILTER (gtk_custom_filter_new ((GtkCustomFilterFunc) filter_search_results, self, NULL));
+  expr = gtk_property_expression_new (GTK_TYPE_STACK_PAGE, NULL, "visible");
 
   model = G_LIST_MODEL (adw_view_stack_get_pages (priv->pages_stack));
-  model = G_LIST_MODEL (gtk_filter_list_model_new (model, priv->page_filter));
+  model = G_LIST_MODEL (gtk_filter_list_model_new (model, GTK_FILTER (gtk_bool_filter_new (expr))));
   model = G_LIST_MODEL (gtk_map_list_model_new (model,
                                                 (GtkMapListModelMapFunc) preferences_page_to_rows,
                                                 NULL,
                                                 NULL));
   model = G_LIST_MODEL (gtk_flatten_list_model_new (model));
-  priv->filter_model = gtk_filter_list_model_new (model, priv->row_filter);
+  priv->filter_model = gtk_filter_list_model_new (model, priv->filter);
 
   gtk_search_entry_set_key_capture_widget (priv->search_entry, GTK_WIDGET (self));
 }
@@ -724,7 +714,7 @@ adw_preferences_window_buildable_init (GtkBuildableIface *iface)
  *
  * Returns: the newly created `AdwPreferencesWindow`
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 GtkWidget *
 adw_preferences_window_new (void)
@@ -739,7 +729,7 @@ adw_preferences_window_new (void)
  *
  * Adds a preferences page to @self.
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 void
 adw_preferences_window_add (AdwPreferencesWindow *self,
@@ -759,9 +749,6 @@ adw_preferences_window_add (AdwPreferencesWindow *self,
   g_object_bind_property (page, "title", stack_page, "title", G_BINDING_SYNC_CREATE);
   g_object_bind_property (page, "use-underline", stack_page, "use-underline", G_BINDING_SYNC_CREATE);
   g_object_bind_property (page, "name", stack_page, "name", G_BINDING_SYNC_CREATE);
-
-  priv->n_pages++;
-  update_view_switcher (self);
 }
 
 /**
@@ -771,7 +758,7 @@ adw_preferences_window_add (AdwPreferencesWindow *self,
  *
  * Removes a page from @self.
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 void
 adw_preferences_window_remove (AdwPreferencesWindow *self,
@@ -788,9 +775,6 @@ adw_preferences_window_remove (AdwPreferencesWindow *self,
     adw_view_stack_remove (priv->pages_stack, GTK_WIDGET (page));
   else
     ADW_CRITICAL_CANNOT_REMOVE_CHILD (self, page);
-
-  priv->n_pages--;
-  update_view_switcher (self);
 }
 
 /**
@@ -801,7 +785,7 @@ adw_preferences_window_remove (AdwPreferencesWindow *self,
  *
  * Returns: (transfer none) (nullable): the visible page
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 AdwPreferencesPage *
 adw_preferences_window_get_visible_page (AdwPreferencesWindow *self)
@@ -822,7 +806,7 @@ adw_preferences_window_get_visible_page (AdwPreferencesWindow *self)
  *
  * Makes @page the visible page of @self.
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 void
 adw_preferences_window_set_visible_page (AdwPreferencesWindow *self,
@@ -846,7 +830,7 @@ adw_preferences_window_set_visible_page (AdwPreferencesWindow *self,
  *
  * Returns: (transfer none) (nullable): the name of the visible page
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 const char *
 adw_preferences_window_get_visible_page_name (AdwPreferencesWindow *self)
@@ -867,9 +851,9 @@ adw_preferences_window_get_visible_page_name (AdwPreferencesWindow *self)
  *
  * Makes the page with the given name visible.
  *
- * See [property@PreferencesWindow:visible-page].
+ * See [property@ViewStack:visible-child].
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 void
 adw_preferences_window_set_visible_page_name (AdwPreferencesWindow *self,
@@ -885,14 +869,14 @@ adw_preferences_window_set_visible_page_name (AdwPreferencesWindow *self,
 }
 
 /**
- * adw_preferences_window_get_search_enabled:
+ * adw_preferences_window_get_search_enabled: (attributes org.gtk.Method.get_property=search-enabled)
  * @self: a preferences window
  *
  * Gets whether search is enabled for @self.
  *
  * Returns: whether search is enabled for @self.
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 gboolean
 adw_preferences_window_get_search_enabled (AdwPreferencesWindow *self)
@@ -907,13 +891,13 @@ adw_preferences_window_get_search_enabled (AdwPreferencesWindow *self)
 }
 
 /**
- * adw_preferences_window_set_search_enabled:
+ * adw_preferences_window_set_search_enabled: (attributes org.gtk.Method.set_property=search-enabled)
  * @self: a preferences window
  * @search_enabled: whether search is enabled
  *
  * Sets whether search is enabled for @self.
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 void
 adw_preferences_window_set_search_enabled (AdwPreferencesWindow *self,
@@ -943,7 +927,7 @@ adw_preferences_window_set_search_enabled (AdwPreferencesWindow *self,
 }
 
 /**
- * adw_preferences_window_set_can_navigate_back:
+ * adw_preferences_window_set_can_navigate_back: (attributes org.gtk.Method.set_property=can-navigate-back)
  * @self: a preferences window
  * @can_navigate_back: the new value
  *
@@ -960,9 +944,7 @@ adw_preferences_window_set_search_enabled (AdwPreferencesWindow *self,
  *
  * For right-to-left locales, gestures and shortcuts are reversed.
  *
- * Has no effect for subpages added with [method@PreferencesWindow.push_subpage].
- *
- * Deprecated: 1.4: Use [method@NavigationPage.set_can_pop] instead.
+ * Since: 1.0
  */
 void
 adw_preferences_window_set_can_navigate_back (AdwPreferencesWindow *self,
@@ -985,14 +967,14 @@ adw_preferences_window_set_can_navigate_back (AdwPreferencesWindow *self,
 }
 
 /**
- * adw_preferences_window_get_can_navigate_back:
+ * adw_preferences_window_get_can_navigate_back: (attributes org.gtk.Method.get_property=can-navigate-back)
  * @self: a preferences window
  *
  * Gets whether gestures and shortcuts for closing subpages are enabled.
  *
  * Returns: whether gestures and shortcuts are enabled.
  *
- * Deprecated: 1.4: Use [method@NavigationPage.get_can_pop] instead.
+ * Since: 1.0
  */
 gboolean
 adw_preferences_window_get_can_navigate_back (AdwPreferencesWindow *self)
@@ -1016,7 +998,7 @@ adw_preferences_window_get_can_navigate_back (AdwPreferencesWindow *self)
  * The transition can be cancelled by the user, in which case visible child will
  * change back to the previously visible child.
  *
- * Deprecated: 1.4: Use [method@PreferencesWindow.push_subpage] instead.
+ * Since: 1.0
  */
 void
 adw_preferences_window_present_subpage (AdwPreferencesWindow *self,
@@ -1051,7 +1033,7 @@ adw_preferences_window_present_subpage (AdwPreferencesWindow *self,
  *
  * If there is no presented subpage, this does nothing.
  *
- * Deprecated: 1.4: Use [method@PreferencesWindow.pop_subpage] instead.
+ * Since: 1.0
  */
 void
 adw_preferences_window_close_subpage (AdwPreferencesWindow *self)
@@ -1065,56 +1047,7 @@ adw_preferences_window_close_subpage (AdwPreferencesWindow *self)
   if (priv->subpage == NULL)
     return;
 
-  adw_leaflet_set_visible_child (priv->subpages_leaflet, GTK_WIDGET (priv->subpages_nav_view));
-}
-
-/**
- * adw_preferences_window_push_subpage:
- * @self: a preferences window
- * @page: the subpage
- *
- * Pushes @page onto the subpage stack of @self.
- *
- * The page will be automatically removed when popped.
- *
- * Since: 1.4
- * Deprecated: 1.6: Use [class@PreferencesDialog].
- */
-void
-adw_preferences_window_push_subpage (AdwPreferencesWindow *self,
-                                     AdwNavigationPage    *page)
-{
-  AdwPreferencesWindowPrivate *priv;
-
-  g_return_if_fail (ADW_IS_PREFERENCES_WINDOW (self));
-  g_return_if_fail (ADW_IS_NAVIGATION_PAGE (page));
-
-  priv = adw_preferences_window_get_instance_private (self);
-
-  adw_navigation_view_push (priv->subpages_nav_view, page);
-}
-
-/**
- * adw_preferences_window_pop_subpage:
- * @self: a preferences window
- *
- * Pop the visible page from the subpage stack of @self.
- *
- * Returns: `TRUE` if a page has been popped
- *
- * Since: 1.4
- * Deprecated: 1.6: Use [class@PreferencesDialog].
- */
-gboolean
-adw_preferences_window_pop_subpage (AdwPreferencesWindow *self)
-{
-  AdwPreferencesWindowPrivate *priv;
-
-  g_return_val_if_fail (ADW_IS_PREFERENCES_WINDOW (self), FALSE);
-
-  priv = adw_preferences_window_get_instance_private (self);
-
-  return adw_navigation_view_pop (priv->subpages_nav_view);
+  adw_leaflet_set_visible_child (priv->subpages_leaflet, priv->preferences);
 }
 
 /**
@@ -1126,7 +1059,7 @@ adw_preferences_window_pop_subpage (AdwPreferencesWindow *self)
  *
  * See [method@ToastOverlay.add_toast].
  *
- * Deprecated: 1.6: Use [class@PreferencesDialog].
+ * Since: 1.0
  */
 void
 adw_preferences_window_add_toast (AdwPreferencesWindow *self,
