@@ -3,7 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * Author: Alice Mikhaylenko <alice.mikhaylenko@puri.sm>
+ * Author: Alexander Mikhaylenko <alexander.mikhaylenko@puri.sm>
  */
 
 #pragma once
@@ -44,7 +44,4 @@ void adw_tab_setup_extra_drop_target (AdwTab        *self,
                                       GType         *types,
                                       gsize          n_types);
 
-void adw_tab_set_extra_drag_preload (AdwTab   *self,
-                                     gboolean  preload);
-
 G_END_DECLS
