@@ -5,12 +5,12 @@
  */
 
 #include "config.h"
-#include <glib/gi18n.h>
 
 #include "adw-toast-overlay.h"
 
 #include "adw-animation-util.h"
 #include "adw-easing.h"
+#include "adw-macros-private.h"
 #include "adw-timed-animation.h"
 #include "adw-toast-private.h"
 #include "adw-toast-widget-private.h"
@@ -36,9 +36,6 @@
  * main child, on top of which it can display a [class@Toast], overlaid.
  * Toasts can be shown with [method@ToastOverlay.add_toast].
  *
- * Use [method@ToastOverlay.dismiss_all] to dismiss all toasts at once, or
- * [method@Toast.dismiss] to dismiss a single toast.
- *
  * See [class@Toast] for details.
  *
  * ## CSS nodes
@@ -66,7 +63,9 @@
  *
  * ## Accessibility
  *
- * `AdwToastOverlay` uses the [enum@Gtk.AccessibleRole.GROUP] role.
+ * `AdwToastOverlay` uses the `GTK_ACCESSIBLE_ROLE_TAB_GROUP` role.
+ *
+ * Since: 1.0
  */
 
 typedef struct {
@@ -78,7 +77,6 @@ typedef struct {
   AdwAnimation *show_animation;
   AdwAnimation *hide_animation;
 
-  gulong shown_id;
   gulong dismissed_id;
   gboolean postponing;
 } ToastInfo;
@@ -112,8 +110,6 @@ static GtkBuildableIface *parent_buildable_iface;
 static void
 free_toast_info (ToastInfo *info)
 {
-  if (info->shown_id && info->show_animation)
-    g_signal_handler_disconnect (info->show_animation, info->shown_id);
   if (info->dismissed_id && info->toast)
     g_signal_handler_disconnect (info->toast, info->dismissed_id);
 
@@ -194,8 +190,6 @@ hide_current_toast (AdwToastOverlay *self)
   info->hide_animation =
     adw_timed_animation_new (GTK_WIDGET (self), 1, 0, HIDE_DURATION, target);
 
-  adw_timed_animation_set_easing (ADW_TIMED_ANIMATION (info->hide_animation), ADW_EASE);
-
   g_signal_connect_swapped (info->hide_animation, "done",
                             G_CALLBACK (hide_done_cb), info);
 
@@ -246,17 +240,8 @@ show_toast (AdwToastOverlay *self,
             ToastInfo       *info)
 {
   AdwAnimationTarget *target;
-  const char *title, *button_label;
-  char *announcement;
 
-  if (info->widget) {
-    /* The toast's hide animation is currently playing. Complete it immediately.
-     * hide_done_cb() will clear the widget.
-     */
-    g_assert (info->hide_animation);
-    adw_animation_skip (info->hide_animation);
-    g_assert (!info->widget);
-  }
+  g_assert (!info->widget);
 
   self->current_toast = info;
 
@@ -271,33 +256,10 @@ show_toast (AdwToastOverlay *self,
                              self->hiding_toasts ? REPLACE_DURATION : SHOW_DURATION,
                              target);
 
-  adw_timed_animation_set_easing (ADW_TIMED_ANIMATION (info->show_animation), ADW_EASE);
-
-  info->shown_id = g_signal_connect_swapped (info->show_animation, "done",
-                                             G_CALLBACK (show_done_cb), info);
+  g_signal_connect_swapped (info->show_animation, "done",
+                            G_CALLBACK (show_done_cb), info);
 
   adw_animation_play (info->show_animation);
-
-  title = adw_toast_get_title (info->toast);
-  button_label = adw_toast_get_button_label (info->toast);
-
-  if (title && button_label) {
-    announcement = g_strdup_printf (_("A toast appeared: %s, has a button: %s"),
-                                    title, button_label);
-  } else if (title && !button_label) {
-    announcement = g_strdup_printf (_("A toast appeared: %s"), title);
-  } else if (!title && button_label) {
-    announcement = g_strdup_printf (_("A toast appeared, has a button: %s"),
-                                    button_label);
-  } else {
-    announcement = g_strdup (_("A toast appeared"));
-  }
-
-  gtk_accessible_announce (GTK_ACCESSIBLE (self),
-                           announcement,
-                           GTK_ACCESSIBLE_ANNOUNCEMENT_PRIORITY_MEDIUM);
-
-  g_free (announcement);
 }
 
 static int
@@ -531,14 +493,15 @@ adw_toast_overlay_class_init (AdwToastOverlayClass *klass)
   object_class->set_property = adw_toast_overlay_set_property;
 
   widget_class->compute_expand = adw_widget_compute_expand;
-  widget_class->get_request_mode = adw_widget_get_request_mode;
   widget_class->measure = adw_toast_overlay_measure;
   widget_class->size_allocate = adw_toast_overlay_size_allocate;
 
   /**
-   * AdwToastOverlay:child:
+   * AdwToastOverlay:child: (attributes org.gtk.Property.get=adw_toast_overlay_get_child org.gtk.Property.set=adw_toast_overlay_set_child)
    *
    * The child widget.
+   *
+   * Since: 1.0
    */
   props[PROP_CHILD] =
     g_param_spec_object ("child", NULL, NULL,
@@ -591,6 +554,8 @@ adw_toast_overlay_buildable_init (GtkBuildableIface *iface)
  * Creates a new `AdwToastOverlay`.
  *
  * Returns: the new created `AdwToastOverlay`
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_toast_overlay_new (void)
@@ -599,12 +564,14 @@ adw_toast_overlay_new (void)
 }
 
 /**
- * adw_toast_overlay_get_child:
+ * adw_toast_overlay_get_child: (attributes org.gtk.Method.get_property=child)
  * @self: a toast overlay
  *
  * Gets the child widget of @self.
  *
  * Returns: (nullable) (transfer none): the child widget of @self
+ *
+ * Since: 1.0
  */
 GtkWidget *
 adw_toast_overlay_get_child (AdwToastOverlay *self)
@@ -615,11 +582,13 @@ adw_toast_overlay_get_child (AdwToastOverlay *self)
 }
 
 /**
- * adw_toast_overlay_set_child:
+ * adw_toast_overlay_set_child: (attributes org.gtk.Method.set_property=child)
  * @self: a toast overlay
  * @child: (nullable): the child widget
  *
  * Sets the child widget of @self.
+ *
+ * Since: 1.0
  */
 void
 adw_toast_overlay_set_child (AdwToastOverlay *self,
@@ -631,9 +600,6 @@ adw_toast_overlay_set_child (AdwToastOverlay *self,
   if (self->child == child)
     return;
 
-  if (child)
-    g_return_if_fail (gtk_widget_get_parent (child) == NULL);
-
   if (self->child)
     gtk_widget_unparent (self->child);
 
@@ -660,6 +626,8 @@ adw_toast_overlay_set_child (AdwToastOverlay *self,
  *
  * If called on a toast currently in the queue, the toast will be bumped
  * forward to be shown as soon as possible.
+ *
+ * Since: 1.0
  */
 void
 adw_toast_overlay_add_toast (AdwToastOverlay *self,
@@ -726,22 +694,3 @@ adw_toast_overlay_add_toast (AdwToastOverlay *self,
     g_assert_not_reached ();
   }
 }
-
-/**
- * adw_toast_overlay_dismiss_all:
- * @self: a toast overlay
- *
- * Dismisses all displayed toasts.
- *
- * Use [method@Toast.dismiss] to dismiss a single toast.
- *
- * Since: 1.7
- */
-void
-adw_toast_overlay_dismiss_all (AdwToastOverlay *self)
-{
-  g_return_if_fail (ADW_IS_TOAST_OVERLAY (self));
-
-  g_clear_pointer (&self->current_toast, dismiss_and_free_toast_info);
-  g_queue_clear_full (self->queue, (GDestroyNotify) dismiss_and_free_toast_info);
-}
