@@ -6,10 +6,12 @@
 
 #include <adwaita.h>
 
+int notified;
+
 static void
-increment (int *data)
+notify_cb (GtkWidget *widget, gpointer data)
 {
-  (*data)++;
+  notified++;
 }
 
 static void
@@ -39,12 +41,10 @@ test_adw_combo_row_set_for_enum (void)
   item = g_list_model_get_item (model, 0);
   g_assert_true (ADW_IS_ENUM_LIST_ITEM (item));
   g_assert_cmpstr (adw_enum_list_item_get_nick (item), ==, "horizontal");
-  g_object_unref (item);
 
   item = g_list_model_get_item (model, 1);
   g_assert_true (ADW_IS_ENUM_LIST_ITEM (item));
   g_assert_cmpstr (adw_enum_list_item_get_nick (item), ==, "vertical");
-  g_object_unref (item);
 
   g_assert_finalize_object (row);
 }
@@ -54,11 +54,12 @@ test_adw_combo_row_selected (void)
 {
   AdwComboRow *row = g_object_ref_sink (ADW_COMBO_ROW (adw_combo_row_new ()));
   GListModel *model;
-  int selected = 0, notified = 0;
+  int selected = 0;
 
   g_assert_nonnull (row);
 
-  g_signal_connect_swapped (row, "notify::selected", G_CALLBACK (increment), &notified);
+  notified = 0;
+  g_signal_connect (row, "notify::selected", G_CALLBACK (notify_cb), NULL);
 
   g_object_get (row, "selected", &selected, NULL);
   g_assert_cmpint (selected, ==, -1);
@@ -90,11 +91,11 @@ test_adw_combo_row_use_subtitle (void)
 {
   AdwComboRow *row = g_object_ref_sink (ADW_COMBO_ROW (adw_combo_row_new ()));
   gboolean use_subtitle = FALSE;
-  int notified = 0;
 
   g_assert_nonnull (row);
 
-  g_signal_connect_swapped (row, "notify::use-subtitle", G_CALLBACK (increment), &notified);
+  notified = 0;
+  g_signal_connect (row, "notify::use-subtitle", G_CALLBACK (notify_cb), NULL);
 
   g_assert_false (adw_combo_row_get_use_subtitle (row));
 
